<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\157\162\x64\120\162\x65\163\x73"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\157\x64\145\x6a\163"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\x74\x61\x74\151\x63"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\171\164\150\x6f\x6e"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\x52\145\166\x65\162\163\145\120\x72\157\x78\171"; private const VARNISH_CACHE_SERVER = "\x31\62\67\56\x30\56\60\56\61\72\x36\60\x38\61"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\x46\123\137\115\x45\124\x48\117\x44" => ["\166\141\154\165\x65" => "\144\151\162\145\143\164", "\162\141\x77" => false], "\127\120\137\104\x45\102\125\x47\x5f\x44\111\123\120\x4c\101\x59" => ["\x76\x61\154\x75\145" => "\x66\141\x6c\163\145", "\162\141\167" => true], "\x57\x50\137\x44\105\x42\125\107\137\x4c\117\x47" => ["\166\141\x6c\x75\x65" => "\x74\x72\x75\145", "\x72\141\167" => true], "\103\x4f\116\x43\x41\124\105\x4e\101\124\x45\137\x53\103\122\x49\x50\x54\x53" => ["\166\141\154\x75\x65" => "\146\141\x6c\x73\145", "\162\x61\x77" => true], "\101\125\x54\117\123\x41\x56\105\x5f\111\116\124\x45\x52\126\101\114" => ["\166\141\154\x75\x65" => 600, "\x72\141\167" => true], "\127\120\137\x50\117\123\124\137\x52\x45\x56\x49\x53\111\117\x4e\123" => ["\x76\x61\154\x75\x65" => 5, "\x72\x61\x77" => true], "\x45\x4d\120\x54\131\x5f\124\x52\x41\x53\110\x5f\x44\x41\x59\123" => ["\x76\141\154\x75\145" => 21, "\x72\x61\x77" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\120\137\x41\x4c\114\117\127\x5f\115\125\x4c\x54\x49\123\111\x54\x45" => ["\166\141\154\x75\x65" => "\x74\162\165\x65", "\x72\x61\x77" => true], "\115\x55\x4c\124\111\123\111\124\105" => ["\x76\141\x6c\165\x65" => "\x74\162\x75\x65", "\x72\x61\x77" => true], "\x53\125\102\x44\x4f\115\x41\x49\116\x5f\111\116\123\124\101\x4c\114" => ["\166\141\x6c\x75\x65" => "\x66\141\x6c\x73\x65", "\162\x61\167" => true], "\x44\x4f\x4d\x41\111\x4e\x5f\103\x55\122\122\105\116\x54\137\x53\x49\x54\105" => ["\166\141\154\165\x65" => '', "\162\x61\167" => false], "\120\101\x54\110\x5f\103\x55\x52\122\105\x4e\124\137\x53\111\x54\x45" => ["\166\141\154\165\145" => "\x2f", "\162\x61\167" => false], "\x53\x49\124\105\137\111\x44\x5f\x43\125\122\122\105\116\x54\137\123\111\124\105" => ["\166\141\154\x75\145" => 1, "\x72\141\167" => true], "\102\114\x4f\x47\137\x49\x44\x5f\103\125\122\122\105\x4e\124\x5f\x53\x49\124\x45" => ["\166\141\154\x75\x65" => 1, "\162\x61\x77" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto efd73; a572f: $this->siteEntityManager = $siteEntityManager; goto A2ca2; F98d2: $this->domainNameParser = $domainNameParser; goto F8fa7; b6a04: $this->databaseServerEntityManager = $databaseServerEntityManager; goto F0637; Be27e: parent::__construct($translator, $logger); goto A5bba; F0637: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto F98d2; B1da2: $this->databaseUserEntityManager = $databaseUserEntityManager; goto b6a04; A2ca2: $this->certificateEntityManager = $certificateEntityManager; goto A2e30; A2e30: $this->databaseEntityManager = $databaseEntityManager; goto B1da2; F8fa7: $this->validator = $validator; goto Be27e; efd73: $this->configManager = $configManager; goto a572f; A5bba: } public function index(Request $request) : Response { goto edcf5; a464b: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\137\163\x69\164\x65\x73")); goto E4ae2; d941e: return $response; goto b1007; bc788: $user = $this->getUser(); goto Cbc51; fced1: if (true === $hasPermissions) { goto D8292; } goto a464b; edcf5: $hasPermissions = $this->hasPermissions(); goto fced1; B06d9: ffc04: goto d941e; e2b2f: D8292: goto bc788; Cbc51: $response = $this->render("\106\x72\157\156\164\x65\156\x64\x2f\123\x69\x74\x65\57\x4e\145\x77\57\151\x6e\144\145\x78\x2e\150\164\155\154\x2e\164\167\151\147", ["\x75\x73\145\x72" => $user]); goto B06d9; E4ae2: goto ffc04; goto e2b2f; b1007: } public function newPythonSite(Request $request) : Response { goto Fd527; Cec2a: f88e6: goto d649b; Eb65f: A7bfb: goto F2834; c4c5b: d60a1: goto Eb65f; f59a2: a5c77: goto bd4a8; bd4a8: $user = $this->getUser(); goto dd4c1; D2294: if (!(false === is_null($response))) { goto d60a1; } goto F3a8f; Fb965: $form = $this->createPythonSiteForm($pythonSettings); goto e481b; F3a8f: return $response; goto c4c5b; e481b: if (!(true === $request->isMethod("\120\117\x53\124"))) { goto bd2e8; } goto eaa3c; Ce439: $response = $this->render("\x46\x72\157\x6e\164\x65\x6e\x64\57\123\x69\x74\x65\57\x4e\145\167\x2f\x70\x79\x74\150\157\x6e\x2e\150\x74\x6d\x6c\x2e\x74\x77\151\x67", ["\x75\x73\145\x72" => $user, "\x66\x6f\162\155" => $form->createView(), "\x66\157\162\x6d\x45\162\162\157\x72\x73" => $this->formErrors]); goto Cec2a; F2834: bd2e8: goto Ce439; bd08e: $response = $this->handleCreatePythonSiteForm($request, $form); goto D2294; eaa3c: $form->handleRequest($request); goto af8fa; a45a3: if (true === $hasPermissions) { goto a5c77; } goto Ffa8e; Ffa8e: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\163\x69\164\145\163")); goto B77f2; Fd527: $hasPermissions = $this->hasPermissions(); goto a45a3; d649b: return $response; goto cfaec; B77f2: goto f88e6; goto f59a2; dd4c1: $pythonSettings = new PythonSettingsEntity(); goto Fb965; af8fa: if (!(true === $form->isSubmitted())) { goto A7bfb; } goto bd08e; cfaec: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto F5ad2; cbe60: return $form; goto D27af; F5ad2: $form = $this->createForm("\101\x70\160\134\106\157\162\x6d\134\123\x69\x74\145\x4e\x65\x77\120\x79\x74\150\157\x6e\x54\x79\x70\145", $pythonSettings, ["\141\x63\x74\151\x6f\x6e" => $this->generateUrl("\143\x6c\160\x5f\163\151\x74\x65\137\160\171\164\150\x6f\x6e\137\x6e\x65\x77"), "\x6d\x65\x74\150\x6f\x64" => "\x50\117\123\x54", "\141\164\164\162" => ["\151\144" => "\x6e\x65\167\55\x70\x79\164\150\x6f\156\x2d\x73\x69\164\145\55\146\x6f\x72\x6d"]]); goto a2f2e; a2f2e: $form->add("\x73\165\142\155\151\164", SubmitType::class, ["\141\x74\164\x72" => ["\143\x6c\x61\x73\x73" => "\x62\x74\x6e\x20\142\x74\156\x2d\x6c\147\40\x62\164\156\x2d\x62\x6c\x75\x65"], "\154\141\x62\145\154" => "\103\x72\x65\141\164\x65"]); goto cbe60; D27af: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto D646a; D646a: if (true === $form->isValid()) { goto D5666; } goto E2e3f; c0aaf: D5666: goto D151d; D151d: try { goto f2522; cc815: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\x69\x74\x65\163")); goto a7b54; c1c5e: $port = $form->get("\x70\x6f\162\164")->getData(); goto dceef; ee7ce: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto a280c; efe7e: if (false === is_null($vhostTemplateEntity)) { goto d6326; } goto e86b8; dceef: $siteUser = $form->get("\163\x69\164\x65\125\x73\x65\162")->getData(); goto cd02e; Bcac1: d6326: goto d74db; Aee93: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto e4dc6; Da261: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto efe7e; a7b54: return $response; goto E0f8b; e41d1: $domainName = $form->get("\144\157\155\x61\x69\156\x4e\141\x6d\x65")->getData(); goto Eb65c; A172d: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto Da261; a280c: $session->getFlashBag()->set("\x73\x75\x63\143\145\x73\163", $this->translator->trans("\x53\x69\x74\x65\40\x68\141\x73\x20\x62\145\145\156\x20\x63\162\145\x61\164\x65\x64\56")); goto cc815; e4dc6: $eventData = ["\163\151\164\x65" => $domainName, "\x73\151\x74\145\x55\163\x65\x72" => $siteUser, "\x70\x79\x74\x68\x6f\x6e\126\x65\x72\163\x69\157\156" => $pythonVersion, "\160\x6f\162\x74" => $port]; goto ee7ce; d74db: $user = $this->getUser(); goto Aee93; Eb65c: $pythonVersion = $form->get("\x70\171\x74\x68\x6f\156\126\145\162\x73\x69\157\x6e")->getData(); goto c1c5e; ed8f2: goto Baa5d; goto Bcac1; E0f8b: Baa5d: goto E5dcb; cd02e: $siteUserPassword = $form->get("\163\x69\164\145\125\163\145\162\120\141\x73\x73\x77\x6f\x72\x64")->getData(); goto A172d; e86b8: throw new \Exception(sprintf("\x56\150\157\x73\x74\x20\x74\x65\x6d\160\154\x61\164\x65\40\x22\45\x73\42\40\x6e\157\x74\40\146\157\x75\156\144\x2e", $vhostTemplateName)); goto ed8f2; f2522: $session = $request->getSession(); goto e41d1; E5dcb: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\147\x65\162", $this->translator->trans("\x41\x6e\40\x65\162\x72\157\x72\40\150\141\163\40\157\143\x63\x75\162\162\x65\x64\54\40\x65\162\162\157\162\40\x6d\145\163\x73\141\x67\145\72\x20\x25\145\x72\x72\x6f\x72\x4d\x65\163\163\141\147\145\45", ["\45\x65\162\162\157\x72\x4d\145\x73\x73\141\147\145\45" => $e->getMessage()])); } goto D75d2; E2e3f: $this->formErrors = $this->getErrorMessages($form); goto Ef991; D75d2: B21ef: goto d4b1d; Ef991: goto B21ef; goto c0aaf; d4b1d: } public function newReverseProxy(Request $request) : Response { goto B1d46; d6f36: return $response; goto E8cea; Bf1fd: $form->handleRequest($request); goto C5764; B0378: $response = $this->handleReverseProxyForm($request, $form); goto Ab6d4; a534c: b9b0b: goto d6f36; f5506: if (!(true === $request->isMethod("\x50\x4f\x53\x54"))) { goto b37ad; } goto Bf1fd; Daa1d: goto b9b0b; goto d84df; d5396: b37ad: goto fb4fa; C5764: if (!(true === $form->isSubmitted())) { goto e5799; } goto B0378; d84df: b0616: goto a6862; a6862: $user = $this->getUser(); goto Ebbf6; Bd761: e5799: goto d5396; Afc87: $response = $this->redirect($this->generateUrl("\143\x6c\160\137\x73\x69\x74\x65\x73")); goto Daa1d; fb4fa: $response = $this->render("\106\162\157\156\x74\145\x6e\x64\57\x53\x69\x74\145\x2f\x4e\145\167\x2f\x72\x65\x76\x65\x72\x73\145\55\160\162\157\170\171\x2e\x68\164\x6d\x6c\56\164\167\151\147", ["\x75\x73\x65\x72" => $user, "\x66\x6f\x72\x6d" => $form->createView(), "\146\157\162\155\105\x72\x72\157\x72\x73" => $this->formErrors]); goto a534c; Ebbf6: $form = $this->createReverseProxyForm(); goto f5506; ae108: if (true === $hasPermissions) { goto b0616; } goto Afc87; Ab6d4: if (!(false === is_null($response))) { goto f9c11; } goto F7b5e; B1d46: $hasPermissions = $this->hasPermissions(); goto ae108; F7b5e: return $response; goto b5e87; b5e87: f9c11: goto Bd761; E8cea: } private function createReverseProxyForm() : Form { goto c1751; c1751: $form = $this->createForm("\101\160\x70\x5c\106\157\162\155\134\123\x69\x74\145\116\145\167\122\145\166\145\x72\163\145\x50\162\157\170\171\124\171\x70\145", [], ["\x61\x63\x74\151\x6f\156" => $this->generateUrl("\x63\x6c\x70\137\163\151\164\145\x5f\x72\x65\x76\145\162\163\x65\x5f\160\x72\x6f\170\171\x5f\x6e\x65\167"), "\x6d\x65\x74\150\x6f\144" => "\120\117\123\x54", "\x61\x74\164\x72" => ["\151\144" => "\x6e\x65\167\x2d\x72\x65\166\x65\x72\x73\x65\x2d\160\x72\157\x78\171\55\146\x6f\x72\x6d"]]); goto ea1a0; ea1a0: $form->add("\163\165\x62\x6d\x69\x74", SubmitType::class, ["\x61\164\164\x72" => ["\143\154\x61\x73\x73" => "\x62\x74\156\x20\142\164\x6e\x2d\154\x67\x20\142\164\156\x2d\x62\154\x75\145"], "\x6c\141\x62\145\154" => "\103\162\x65\141\164\x65"]); goto eb725; eb725: return $form; goto A250b; A250b: } private function handleReverseProxyForm(Request $request, Form $form) { goto b3f47; F4560: $this->formErrors = $this->getErrorMessages($form); goto d8b5c; b6369: try { goto d0886; A0e4b: $session->getFlashBag()->set("\x73\x75\x63\143\x65\163\x73", $this->translator->trans("\122\145\166\145\x72\163\x65\x20\x50\162\x6f\x78\x79\x20\x68\x61\x73\x20\142\x65\x65\156\40\143\162\x65\141\164\145\x64\56")); goto b6fc1; D03e1: throw new \Exception(sprintf("\126\x68\157\163\x74\x20\164\145\x6d\160\154\141\x74\x65\x20\42\45\x73\42\40\x6e\x6f\164\40\x66\x6f\165\156\144\56", $vhostTemplateName)); goto Dc836; b6fc1: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\163\x69\164\145\x73")); goto ecb56; Db074: if (false === is_null($vhostTemplateEntity)) { goto d6c54; } goto D03e1; Dc836: goto d12d4; goto Bf6df; ecb56: return $response; goto e479a; e479a: d12d4: goto c862a; Bf6df: d6c54: goto Ffa85; Af051: $siteUser = $form->get("\163\151\x74\145\x55\163\x65\162")->getData(); goto D560d; Bd3b6: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto a72ff; a72ff: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Db074; df607: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto A0e4b; e2ef1: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto d173a; d173a: $eventData = ["\x73\x69\x74\x65" => $domainName, "\x73\x69\164\x65\x55\x73\145\x72" => $siteUser, "\x72\145\x76\x65\x72\x73\x65\120\x72\157\x78\171\x55\x72\154" => $reverseProxyUrl]; goto df607; d0886: $session = $request->getSession(); goto Acdeb; Ef564: $reverseProxyUrl = $form->get("\x72\x65\x76\x65\x72\x73\145\120\162\157\170\171\125\162\x6c")->getData(); goto Bd3b6; D560d: $siteUserPassword = $form->get("\x73\151\164\x65\x55\x73\x65\162\120\141\x73\163\167\x6f\162\144")->getData(); goto Ef564; Acdeb: $domainName = $form->get("\x64\157\155\x61\x69\x6e\x4e\141\155\145")->getData(); goto Af051; Ffa85: $user = $this->getUser(); goto e2ef1; c862a: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\x67\x65\x72", $this->translator->trans("\101\x6e\x20\x65\162\x72\157\x72\x20\150\141\x73\x20\x6f\x63\143\165\162\x72\x65\x64\54\x20\145\162\162\157\x72\40\155\x65\x73\163\141\x67\145\x3a\x20\45\x65\x72\x72\157\162\115\x65\x73\x73\x61\147\x65\45", ["\45\x65\162\162\157\x72\x4d\x65\163\x73\141\147\145\x25" => $e->getMessage()])); } goto e205d; d8b5c: goto F1801; goto eecff; eecff: e3bfe: goto b6369; e205d: F1801: goto b9f12; b3f47: if (true === $form->isValid()) { goto e3bfe; } goto F4560; b9f12: } public function newNodejsSite(Request $request) : Response { goto a8453; De67b: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\x69\x74\145\163")); goto C8e65; bed11: $form->handleRequest($request); goto Da7ca; D0430: b389a: goto D5fba; E6904: if (!(true === $request->isMethod("\120\x4f\x53\124"))) { goto Ab5cc; } goto bed11; d0737: ad58b: goto C51a2; c9ce7: $response = $this->handleCreateNodejsSiteForm($request, $form); goto b3814; E1f97: $response = $this->render("\x46\x72\x6f\x6e\164\x65\156\x64\x2f\123\151\164\145\x2f\116\145\x77\x2f\156\157\144\x65\152\x73\x2e\x68\x74\155\154\56\164\x77\x69\x67", ["\x75\163\145\162" => $user, "\146\x6f\x72\155" => $form->createView(), "\x66\157\162\155\x45\x72\162\x6f\x72\163" => $this->formErrors]); goto d0737; D5fba: e2843: goto dd080; df9c7: $user = $this->getUser(); goto Fb12b; b3814: if (!(false === is_null($response))) { goto b389a; } goto A428f; ccb5c: if (true === $hasPermissions) { goto ddeae; } goto De67b; e46c1: $form = $this->createNodejsSiteForm($nodejsSettings); goto E6904; C51a2: return $response; goto daf00; a8453: $hasPermissions = $this->hasPermissions(); goto ccb5c; dd080: Ab5cc: goto E1f97; Da7ca: if (!(true === $form->isSubmitted())) { goto e2843; } goto c9ce7; A428f: return $response; goto D0430; Fb12b: $nodejsSettings = new NodejsSettingsEntity(); goto e46c1; F33d1: ddeae: goto df9c7; C8e65: goto ad58b; goto F33d1; daf00: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto f25ba; ff7b2: $form->add("\163\x75\142\155\x69\x74", SubmitType::class, ["\141\x74\x74\x72" => ["\x63\x6c\x61\163\163" => "\x62\164\x6e\x20\142\164\x6e\55\x6c\147\x20\x62\x74\x6e\x2d\142\x6c\165\145"], "\154\x61\142\145\x6c" => "\x43\162\x65\x61\164\x65"]); goto E5327; f25ba: $form = $this->createForm("\101\x70\160\x5c\106\x6f\x72\155\134\x53\151\x74\x65\116\145\x77\x4e\157\144\145\152\163\124\171\x70\x65", $nodejsSettings, ["\x61\x63\x74\x69\157\x6e" => $this->generateUrl("\143\x6c\160\137\x73\151\164\x65\137\156\x6f\x64\145\x6a\163\x5f\x6e\145\167"), "\x6d\145\x74\x68\x6f\144" => "\x50\x4f\x53\124", "\141\164\164\x72" => ["\x69\x64" => "\x6e\145\167\55\156\x6f\144\x65\x6a\x73\x2d\163\x69\164\x65\x2d\146\157\x72\x6d"]]); goto ff7b2; E5327: return $form; goto b6891; b6891: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto C3776; Ec351: goto Bdb67; goto ecca5; C3776: if (true === $form->isValid()) { goto Ee77e; } goto Ef2c7; Ef2c7: $this->formErrors = $this->getErrorMessages($form); goto Ec351; ecca5: Ee77e: goto Bf8f9; Bf8f9: try { goto Db8d7; c7b43: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto a7f94; c9f00: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\163\x69\164\145\163")); goto Eb484; Eb484: return $response; goto a6da0; f396f: $eventData = ["\163\151\x74\x65" => $domainName, "\x73\151\164\x65\x55\x73\x65\x72" => $siteUser, "\x6e\157\x64\x65\152\163\x56\x65\x72\163\151\157\156" => $nodejsVersion, "\x70\157\x72\x74" => $port]; goto bb003; a76d5: $user = $this->getUser(); goto a16f9; Ef408: $siteUserPassword = $form->get("\x73\x69\164\x65\x55\x73\x65\162\120\141\163\x73\167\x6f\x72\144")->getData(); goto d41da; a6da0: eafc7: goto a36c8; bb003: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto F9d49; a16f9: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto f396f; B77f0: $domainName = $form->get("\144\157\x6d\141\x69\x6e\116\141\155\x65")->getData(); goto B5b84; Bde76: $port = $form->get("\x70\x6f\x72\x74")->getData(); goto E988a; ee899: goto eafc7; goto c7d47; E988a: $siteUser = $form->get("\x73\151\164\145\125\x73\x65\162")->getData(); goto Ef408; d41da: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto c7b43; B5b84: $nodejsVersion = $form->get("\156\x6f\144\x65\152\x73\x56\x65\x72\x73\151\157\156")->getData(); goto Bde76; a7f94: if (false === is_null($vhostTemplateEntity)) { goto Ab433; } goto a678f; c7d47: Ab433: goto a76d5; Db8d7: $session = $request->getSession(); goto B77f0; a678f: throw new \Exception(sprintf("\x56\150\157\163\164\40\x74\145\155\160\154\x61\x74\145\40\x22\x25\163\42\40\156\x6f\164\x20\146\157\165\156\x64\x2e", $vhostTemplateName)); goto ee899; F9d49: $session->getFlashBag()->set("\x73\165\143\x63\145\x73\x73", $this->translator->trans("\123\151\164\x65\x20\x68\x61\x73\x20\x62\145\x65\x6e\40\143\x72\x65\141\164\x65\x64\56")); goto c9f00; a36c8: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\x67\145\x72", $this->translator->trans("\x41\156\40\x65\x72\162\157\162\40\150\x61\163\x20\x6f\x63\143\x75\162\162\x65\144\54\x20\x65\x72\162\x6f\x72\40\x6d\145\x73\163\141\147\x65\x3a\x20\45\x65\x72\x72\157\x72\x4d\145\163\x73\141\147\145\x25", ["\45\x65\x72\162\x6f\x72\x4d\x65\163\163\141\147\145\45" => $e->getMessage()])); } goto A2ccb; A2ccb: Bdb67: goto fe281; fe281: } public function newStaticSite(Request $request) : Response { goto f993d; d364e: E23f7: goto f52fb; efaf0: $user = $this->getUser(); goto Ec244; Ea614: if (!(true === $request->isMethod("\x50\117\123\124"))) { goto Dbbcd; } goto Dde05; fc658: Dbbcd: goto Eaa9c; ea40d: if (!(true === $form->isSubmitted())) { goto Aea89; } goto be833; Dabb6: return $response; goto d364e; de07a: if (true === $hasPermissions) { goto Ca191; } goto f655c; b600a: if (!(false === is_null($response))) { goto E23f7; } goto Dabb6; f52fb: Aea89: goto fc658; e81c6: Ca191: goto efaf0; f655c: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\151\x74\x65\x73")); goto fc0ee; Eaa9c: $response = $this->render("\x46\x72\x6f\156\x74\x65\x6e\144\57\x53\x69\164\145\57\116\145\x77\57\163\x74\141\164\x69\143\x2e\150\x74\155\x6c\56\x74\167\x69\147", ["\x75\x73\x65\x72" => $user, "\x66\x6f\x72\x6d" => $form->createView(), "\x66\157\x72\x6d\x45\162\162\157\x72\163" => $this->formErrors]); goto Aa3f4; Ec244: $form = $this->createStaticSiteForm(); goto Ea614; fc0ee: goto A1b57; goto e81c6; Aa3f4: A1b57: goto De4ad; Dde05: $form->handleRequest($request); goto ea40d; f993d: $hasPermissions = $this->hasPermissions(); goto de07a; be833: $response = $this->handleCreateStaticSiteForm($request, $form); goto b600a; De4ad: return $response; goto ebc11; ebc11: } private function createStaticSiteForm() : Form { goto C9df5; e911d: $form->add("\163\165\142\x6d\151\164", SubmitType::class, ["\141\x74\x74\162" => ["\143\x6c\x61\163\163" => "\142\x74\156\40\x62\164\156\55\154\x67\x20\142\x74\x6e\55\142\x6c\165\x65"], "\x6c\x61\142\145\154" => "\103\x72\145\x61\164\145"]); goto D980c; D980c: return $form; goto af569; C9df5: $form = $this->createForm("\x41\160\160\134\x46\157\x72\x6d\x5c\123\151\164\x65\x4e\145\x77\123\x74\x61\x74\x69\x63\x54\171\x70\x65", [], ["\141\143\164\x69\x6f\156" => $this->generateUrl("\143\x6c\160\137\163\x69\164\145\137\x73\x74\x61\x74\x69\143\x5f\156\145\x77"), "\155\x65\164\150\x6f\x64" => "\x50\x4f\123\x54", "\x61\164\164\162" => []]); goto e911d; af569: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto d20f6; Ed620: Eac18: goto b916f; Bad86: a9e1d: goto A61ce; bbce5: goto a9e1d; goto Ed620; b916f: try { goto c8254; bed93: C4317: goto F894c; a2e4b: throw new \Exception(sprintf("\x56\150\157\x73\164\40\164\145\155\160\x6c\141\x74\145\40\42\45\163\x22\40\156\157\164\x20\146\x6f\x75\x6e\144\x2e", $vhostTemplateName)); goto f496e; Ef66d: $domainName = $form->get("\144\x6f\155\141\151\x6e\x4e\141\x6d\x65")->getData(); goto Ae724; cbb05: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto A0151; Ae724: $siteUser = $form->get("\163\x69\x74\x65\x55\x73\145\x72")->getData(); goto A0ed9; d8425: if (false === is_null($vhostTemplateEntity)) { goto F2f6a; } goto a2e4b; D791c: $user = $this->getUser(); goto E2bf1; A0151: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto d8425; d6cc7: F2f6a: goto D791c; f794d: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\163\151\164\x65\163")); goto a2401; E2bf1: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto Edbd2; f496e: goto C4317; goto d6cc7; A0ed9: $siteUserPassword = $form->get("\x73\151\x74\145\125\163\145\x72\x50\141\163\x73\167\157\162\144")->getData(); goto cbb05; a2401: return $response; goto bed93; A8b84: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto Fdcdc; Fdcdc: $session->getFlashBag()->set("\x73\x75\x63\143\x65\163\163", $this->translator->trans("\123\x69\164\x65\40\150\141\163\x20\142\145\x65\156\x20\x63\x72\x65\141\164\x65\144\56")); goto f794d; c8254: $session = $request->getSession(); goto Ef66d; Edbd2: $eventData = ["\163\151\164\145" => $domainName, "\163\x69\x74\x65\125\x73\145\162" => $siteUser]; goto A8b84; F894c: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\147\145\x72", $this->translator->trans("\x41\x6e\40\145\162\x72\157\x72\x20\150\x61\x73\40\157\143\x63\x75\162\162\145\144\x2c\40\x65\162\x72\157\x72\40\x6d\145\x73\163\x61\x67\145\x3a\40\x25\145\162\162\157\162\x4d\145\x73\163\x61\x67\x65\x25", ["\45\145\162\162\x6f\x72\x4d\145\x73\163\141\x67\145\45" => $e->getMessage()])); } goto Bad86; a1219: $this->formErrors = $this->getErrorMessages($form); goto bbce5; d20f6: if (true === $form->isValid()) { goto Eac18; } goto a1219; A61ce: } public function newPhpSite(Request $request) : Response { goto f6707; A4ce9: C0c92: goto d2271; D1b53: $response = $this->render("\106\x72\157\156\x74\x65\x6e\x64\57\123\151\x74\145\x2f\116\x65\x77\57\160\x68\x70\x2e\x68\164\x6d\x6c\56\164\167\151\x67", ["\x75\163\145\x72" => $user, "\x66\157\162\155" => $form->createView(), "\x66\157\162\x6d\x45\162\x72\x6f\162\163" => $this->formErrors]); goto eba52; dee7f: Fafbe: goto D1b53; a8162: f569c: goto C86e8; d2271: $user = $this->getUser(); goto e2112; Aeeb0: if (!(true === $request->isMethod("\120\x4f\x53\x54"))) { goto Fafbe; } goto de94d; E77f0: if (!(false === is_null($response))) { goto f569c; } goto f3464; C86e8: f7dae: goto dee7f; f3464: return $response; goto a8162; ed730: if (true === $hasPermissions) { goto C0c92; } goto f0090; f0090: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\151\x74\145\x73")); goto f1a73; de94d: $form->handleRequest($request); goto d1c85; f1a73: goto fd28e; goto A4ce9; fae6f: $response = $this->handleCreatePhpSiteForm($request, $form); goto E77f0; e2112: $form = $this->createPhpSiteForm(); goto Aeeb0; f6707: $hasPermissions = $this->hasPermissions(); goto ed730; d1c85: if (!(true === $form->isSubmitted())) { goto f7dae; } goto fae6f; F9146: return $response; goto d5d13; eba52: fd28e: goto F9146; d5d13: } private function createPhpSiteForm() : Form { goto Fd148; Cf0b6: return $form; goto C7239; Fd148: $form = $this->createForm("\101\160\160\134\x46\x6f\162\155\134\123\151\164\145\x4e\x65\x77\120\150\x70\x54\171\x70\x65", [], ["\141\143\164\151\157\156" => $this->generateUrl("\143\154\x70\x5f\163\x69\164\145\137\160\x68\160\x5f\156\145\x77"), "\155\x65\164\x68\157\144" => "\x50\x4f\123\124", "\x61\x74\x74\x72" => []]); goto E82c2; E82c2: $form->add("\x73\x75\142\155\151\x74", SubmitType::class, ["\x61\x74\164\162" => ["\143\x6c\x61\163\163" => "\x62\164\156\40\142\x74\x6e\x2d\154\x67\40\142\x74\156\x2d\142\x6c\x75\x65"], "\154\x61\x62\x65\154" => "\x43\162\145\x61\164\x65"]); goto Cf0b6; C7239: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto b7efb; af263: A7d42: goto e0807; a5ebd: goto bbb5a; goto af263; b7efb: if (true === $form->isValid()) { goto A7d42; } goto d6a69; e0807: try { goto B0d82; e02c6: $rootDirectory = sprintf("\45\x73\57\x25\x73", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\x2f")); goto E3717; Fe2cb: $eventData = ["\163\151\164\x65" => $domainName, "\x76\150\157\x73\164\x54\x65\155\x70\154\x61\x74\145\x4e\x61\155\x65" => $vhostTemplateName, "\x70\150\160\126\145\162\163\x69\157\x6e" => $phpVersion, "\x73\151\164\145\x55\x73\x65\x72" => $siteUser]; goto c1133; e0782: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto Fe2cb; db463: $domainName = $form->get("\144\x6f\x6d\x61\151\x6e\x4e\141\155\x65")->getData(); goto Cedae; ac0c4: $user = $this->getUser(); goto cf0f5; a9adc: $vhostTemplateName = $form->get("\x61\x70\160\x6c\151\x63\141\x74\x69\x6f\156")->getData(); goto db463; d3a69: $varnishCacheSettings = []; goto c7a8a; D6393: $siteUser = $form->get("\163\151\x74\145\125\163\x65\162")->getData(); goto F59c7; B0d82: $session = $request->getSession(); goto a9adc; f8747: fc41e: goto e0782; Ec785: $session->getFlashBag()->set("\x73\x75\143\143\145\x73\163", $this->translator->trans("\123\151\164\145\x20\150\141\x73\40\x62\145\x65\156\40\x63\162\145\141\164\145\x64\56")); goto fc290; c1133: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto Ec785; f2251: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ccef8; Ccef8: if (false === is_null($vhostTemplateEntity)) { goto De79b; } goto a470b; ae96b: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto f8747; A3528: goto c1ff4; goto cbca0; E3717: c8d97: goto d3a69; a470b: throw new \Exception(sprintf("\x56\150\157\163\164\40\x74\x65\x6d\x70\154\x61\x74\x65\40\x22\x25\163\x22\40\156\x6f\164\x20\x66\157\165\x6e\x64\56", $vhostTemplateName)); goto A3528; Fbd0d: return $response; goto a6d08; F59c7: $siteUserPassword = $form->get("\163\151\164\x65\125\x73\145\162\x50\141\x73\x73\167\x6f\162\144")->getData(); goto f2251; Cedae: $phpVersion = $form->get("\160\x68\160\126\145\162\x73\151\x6f\x6e")->getData(); goto D6393; cf0f5: $rootDirectory = $domainName; goto e2349; fc290: $response = $this->redirect($this->generateUrl("\x63\154\160\137\163\x69\164\145\x73")); goto Fbd0d; c7a8a: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto fc41e; } goto ae96b; a6d08: c1ff4: goto b0e50; e2349: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto c8d97; } goto e02c6; cbca0: De79b: goto ac0c4; b0e50: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\x67\x65\162", $this->translator->trans("\101\156\40\x65\162\162\x6f\162\40\x68\141\x73\x20\x6f\x63\143\165\162\162\145\144\x2c\x20\x65\x72\162\157\162\40\155\145\163\x73\141\147\145\72\x20\45\145\162\162\x6f\x72\115\x65\163\163\x61\x67\x65\x25", ["\45\x65\x72\162\157\x72\x4d\x65\x73\x73\x61\147\145\45" => $e->getMessage()])); } goto fed4e; fed4e: bbb5a: goto C0918; d6a69: $this->formErrors = $this->getErrorMessages($form); goto a5ebd; C0918: } public function newWordPressSite(Request $request) : Response { goto Dab65; De802: D6ae8: goto A64e7; A17b5: c16e7: goto De802; af9b8: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\x73\151\164\x65\163")); goto fa91e; a84b9: a314b: goto a8c78; E1ee2: if (!(false === is_null($response))) { goto C7e34; } goto F8177; F8177: return $response; goto bb372; d466c: if (!(true === $form->isSubmitted())) { goto c16e7; } goto A02fe; a6673: F1ae5: goto e73dd; e73dd: $user = $this->getUser(); goto cf8ec; Fec24: $form->handleRequest($request); goto d466c; D09c5: if (true === $hasPermissions) { goto F1ae5; } goto af9b8; a3423: if (!(true === $request->isMethod("\x50\117\x53\x54"))) { goto D6ae8; } goto Fec24; A02fe: $response = $this->handleCreateWordPressSiteForm($request, $form); goto E1ee2; cf8ec: $form = $this->createWordPressSiteForm(); goto a3423; Dab65: $hasPermissions = $this->hasPermissions(); goto D09c5; a8c78: return $response; goto D4c76; A64e7: $response = $this->render("\x46\x72\157\x6e\x74\145\x6e\x64\x2f\123\x69\x74\145\57\116\x65\167\x2f\x77\157\x72\x64\x70\x72\x65\163\x73\56\x68\164\x6d\x6c\x2e\164\167\151\147", ["\165\163\x65\x72" => $user, "\x66\x6f\162\155" => $form->createView(), "\146\x6f\x72\x6d\x45\x72\x72\x6f\162\163" => $this->formErrors]); goto a84b9; bb372: C7e34: goto A17b5; fa91e: goto a314b; goto a6673; D4c76: } private function createWordPressSiteForm() : Form { goto c34ca; c34ca: $form = $this->createForm("\x41\x70\160\x5c\106\x6f\x72\x6d\134\x53\x69\164\145\x4e\145\x77\127\157\162\144\x50\162\x65\163\163\124\x79\x70\x65", [], ["\x61\x63\164\x69\x6f\x6e" => $this->generateUrl("\x63\154\x70\137\163\x69\164\145\x5f\167\157\162\x64\x70\x72\x65\x73\163\x5f\x6e\x65\x77"), "\155\145\x74\x68\x6f\144" => "\x50\117\123\x54", "\141\164\x74\x72" => ["\x69\x64" => "\156\x65\167\55\167\157\162\x64\x70\x72\x65\x73\163\x2d\x73\x69\164\145\55\x66\157\162\155"]]); goto C2da9; C2da9: $form->add("\163\165\142\x6d\151\164", SubmitType::class, ["\141\164\164\162" => ["\x63\x6c\141\163\163" => "\x62\164\x6e\40\x62\164\x6e\55\x6c\x67\x20\x62\x74\156\55\x62\154\x75\x65"], "\x6c\141\x62\x65\154" => "\x43\162\x65\x61\x74\145"]); goto e8588; e8588: return $form; goto Ca863; Ca863: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto F6fe9; F6fe9: if (true === $form->isValid()) { goto Bbdcf; } goto d807e; d807e: $this->formErrors = $this->getErrorMessages($form); goto A7ca4; a5b50: Bbdcf: goto Bb5c0; Bb5c0: try { goto Be4ba; A58a4: $title = $form->get("\x73\151\x74\x65\124\x69\x74\154\145")->getData(); goto C6278; a172a: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto d9b2f; df44f: $this->siteEntityManager->updateEntity($siteEntity); goto d303d; C6278: $adminUserName = $form->get("\x61\144\155\151\x6e\x55\163\x65\162\116\141\155\x65")->getData(); goto B892c; E921e: $generatedName = $this->generateNameFromDomainName($domainName); goto Aef53; d4467: $siteEntity->addDatabase($databaseEntity); goto a3f1b; B0d44: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto B3c54; Aef53: $siteUser = $form->get("\x73\151\x74\x65\x55\163\145\x72")->getData(); goto f1592; D1066: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto C5b1d; a0551: $eventData = ["\163\151\164\x65" => $domainName, "\x73\x69\x74\x65\125\163\145\162" => $siteUser]; goto Fec51; b496f: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto F2b50; } goto B0d44; F0db8: $url = sprintf("\150\x74\164\160\x73\x3a\57\x2f\45\x73", $siteEntity->getDomainName()); goto A58a4; Be4ba: $user = $this->getUser(); goto b6b9c; c40cc: b592e: goto fb076; be001: $databaseManager->createDatabase($databaseEntity); goto C8289; C8289: $databaseManager->createUser($databaseUserEntity); goto df44f; Ab753: $siteCredentials = [$this->translator->trans("\123\151\164\145") => [$this->translator->trans("\x49\x50\40\x41\x64\144\162\145\x73\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\104\x6f\155\141\x69\x6e\40\x4e\x61\x6d\x65") => sprintf("\150\x74\164\x70\163\72\57\57\x25\163", $domainName), $this->translator->trans("\123\x69\164\x65\40\x55\x73\145\x72") => $siteUser, $this->translator->trans("\x50\x61\163\x73\167\x6f\162\x64") => $siteUserPassword]]; goto d488b; f1569: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto A3c84; a6a2c: $databaseUserEntity->setUserName($databaseUserName); goto e4f6a; B892c: $adminPassword = $form->get("\141\144\x6d\151\x6e\x50\x61\x73\163\x77\x6f\x72\x64")->getData(); goto Af4d5; Af4d5: $adminEmail = $form->get("\x61\x64\x6d\151\156\x45\x6d\141\151\154")->getData(); goto E8e3e; fb076: $session->set("\163\x69\x74\x65\x43\x72\x65\144\x65\x6e\164\151\x61\x6c\x73", $siteCredentials); goto a0551; A3c84: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Ebbe1; c7db9: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto a172a; A59b7: $domainName = $form->get("\x64\157\x6d\141\x69\156\116\141\x6d\145")->getData(); goto E921e; C5b1d: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto F0db8; Cbc24: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto a6a2c; b6b9c: $session = $request->getSession(); goto A59b7; d9e87: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto c3abe; D41d0: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\x69\x74\x65\137\167\x6f\162\144\x70\162\145\163\x73\137\x69\x6e\x73\164\141\x6c\x6c\145\x64")); goto E2656; f1592: $siteUserPassword = $form->get("\x73\x69\164\145\x55\163\x65\162\x50\141\163\163\x77\157\162\144")->getData(); goto c7db9; E94d7: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto e5d7d; A1150: $databaseEntity->setName($databaseName); goto d590e; f7b52: $databaseEntity->addUser($databaseUserEntity); goto d4467; d590e: $databaseEntity->setSite($siteEntity); goto Cbc24; d303d: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto a1900; a1900: $siteCredentials[$this->translator->trans("\x44\141\x74\x61\142\x61\x73\145")] = [$this->translator->trans("\x48\157\x73\x74") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\x50\157\162\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\x44\141\164\x61\142\x61\163\x65\x20\116\x61\155\x65") => $databaseName, $this->translator->trans("\104\x61\164\x61\x62\141\163\145\x20\125\x73\145\x72\40\116\x61\155\145") => $databaseUserName, $this->translator->trans("\104\x61\164\x61\142\141\x73\145\40\125\163\145\162\x20\120\x61\x73\x73\167\157\x72\144") => $databaseUserPassword]; goto A4f20; c3abe: $databaseEntity = $this->databaseEntityManager->createEntity(); goto Cbb0f; Ebbe1: $instance = $request->attributes->get("\151\156\x73\164\141\156\143\145"); goto Ab753; B3c54: F2b50: goto f1569; e4f6a: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto E94d7; d9b2f: $varnishCacheSettings = []; goto b496f; Fec51: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto D41d0; d488b: if (!(false === is_null($siteEntity))) { goto b592e; } goto Aab0a; e5d7d: $databaseUserEntity->setDatabase($databaseEntity); goto f7b52; Aab0a: $databaseName = $this->getUniqueDatabaseName($generatedName); goto D1066; Cbb0f: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto A1150; a3f1b: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto be001; E2656: return $response; goto C259e; E8e3e: $isMultiSite = $form->get("\x6d\165\x6c\x74\151\x53\x69\x74\x65")->getData(); goto d9e87; A4f20: $siteCredentials["\127\157\x72\x64\120\x72\x65\x73\x73"] = [$this->translator->trans("\101\x64\x6d\151\x6e\40\x45\55\115\141\151\x6c") => $adminEmail, $this->translator->trans("\101\x64\x6d\x69\x6e\40\125\x73\145\162\40\x4e\x61\x6d\x65") => $adminUserName, $this->translator->trans("\x41\144\x6d\151\156\40\120\141\x73\x73\x77\x6f\162\x64") => $adminPassword, $this->translator->trans("\x41\x64\x6d\x69\156\x20\125\x72\x6c") => sprintf("\x68\x74\164\x70\163\x3a\x2f\57\x25\x73\57\167\160\55\x61\x64\x6d\151\x6e\x2f", rtrim($domainName, "\x2f"))]; goto c40cc; C259e: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\x67\145\162", $this->translator->trans("\x41\x6e\40\145\162\x72\157\162\40\150\x61\163\40\x6f\x63\x63\165\x72\x72\x65\x64\x2c\40\145\162\x72\157\x72\x20\x6d\145\163\163\x61\147\145\x3a\40\45\145\x72\x72\x6f\162\115\x65\163\163\141\x67\x65\45", ["\45\x65\x72\x72\157\162\x4d\145\x73\163\141\x67\145\x25" => $e->getMessage()])); } goto B39e3; B39e3: a54e9: goto E2feb; A7ca4: goto a54e9; goto a5b50; E2feb: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto d32d9; A74c3: $wordPressInstaller->resetPermissions(); goto B83e3; e99c3: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto bb786; e9c03: $wordPressInstaller->downloadAndExtractLatestVersion(); goto ae5d9; d32d9: $databaseHost = sprintf("\x25\x73\72\45\x73", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto ded87; Dd6ec: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto f9970; bb786: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\154\165\145"], $config["\x72\x61\167"]); c74e1: } goto a5502; b02b2: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\x61\154\165\145"], $config["\162\x61\x77"]); A6ab4: } goto ca45a; f9970: $wordPressInstaller = new WordPressInstaller($siteEntity); goto e9c03; ae5d9: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto e99c3; fa71f: if (!(true === $isMultiSite)) { goto Bf4b2; } goto Fba06; b632b: Bf4b2: goto A74c3; Fba06: $this->wordPressMultiSiteConfigValues["\104\117\115\x41\111\x4e\137\x43\125\x52\x52\105\116\x54\137\123\111\124\105"]["\x76\x61\154\165\x65"] = $siteEntity->getDomainName(); goto b02b2; ded87: $databaseName = $databaseEntity->getName(); goto e159a; e159a: $databaseUserName = $databaseUserEntity->getUserName(); goto Dd6ec; a5502: ad32c: goto fa71f; ca45a: E0377: goto b632b; B83e3: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto b956b; e4249: $phpSiteCreator = new PhpSiteCreator($phpSite); goto A3fe0; E5a10: $siteEntity->setUser($siteUser); goto b44f3; c3d02: $certificateEntity->setCertificate($selfSignedCertificate); goto Fc340; Cc77c: $vhostTemplate = new PhpVhostTemplate($phpSite); goto b0c72; b314f: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Aa144; c47b7: $certificateEntity->setSite($siteEntity); goto A2224; ea5dc: $siteEntity->setDomainName($domainName); goto E5a10; C1ffc: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto B0493; f6ca5: if (true === isset($_ENV["\x41\x50\120\x5f\110\x54\124\120\x33"]) && "\164\x72\165\x65" === $_ENV["\x41\120\120\137\110\124\x54\120\x33"]) { goto a9606; } goto af40f; Aa144: $siteEntity = $this->siteEntityManager->createEntity(); goto B3d64; C590f: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Fd070; C8dc8: $phpSiteCreator->createRootDirectory(); goto c4ba2; a0edf: b432f: goto Bfacb; F2dc4: return $siteEntity; goto c7d68; eca04: b5004: goto Aa238; E2ad9: $phpSite = new PhpSite(); goto c653c; Bfe9b: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto a4933; } goto f6ca5; F42cf: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\x2e\x2f\56\x2e\x2f\162\145\163\x6f\x75\x72\143\145\163\57\x6e\147\151\x6e\170\57\x76\x68\157\x73\164\x5f\x74\x65\x6d\x70\x6c\141\164\x65\x2f\x72\145\144\x69\x72\x65\x63\x74\55\150\164\164\x70\x33"); goto eca04; d0ac6: $siteConstraints = $this->validator->validate($siteEntity); goto e3e72; b0c72: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto f4b3b; D16e8: $siteEntity->setPhpSettings($phpSettingsEntity); goto C428d; e1842: $phpSite->setCertificate($certificateEntity); goto f6891; B85f1: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto f6bd7; A3fe0: $phpSiteCreator->createUser(); goto C8dc8; f49ad: $phpSiteCreator->reloadNginxService(); goto B4708; a4a04: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Fac25; F1713: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto D1596; cbad5: $constraintViolationList->addAll($phpSettingsConstraints); goto F1713; f4bdc: d01fa: goto E1d28; F20d2: $phpSiteCreator->createPrivateKeyAndCertificate(); goto a61f1; Df4da: $phpSettingsEntity = new PhpSettingsEntity(); goto D16e8; Eabb0: Ce928: goto c110c; eebbe: $certificateEntity->setDefaultCertificate(true); goto e5963; f21fc: $subjectAlternativeNames[] = sprintf("\167\167\167\56\x25\x73", $domainName); goto Eabb0; F5847: if (!(false === empty($redirectionVhostTemplate))) { goto b432f; } goto E28a5; f4b3b: $vhostTemplate->resetProcessors(); goto cfe75; B5cf8: b3ff2: goto c4f96; Be66c: f8148: goto ab9e3; a61f1: $phpSiteCreator->createPhpFpmPool(); goto D3c04; C3600: if (!(false === empty($varnishCache))) { goto ce75b; } goto Cde52; Ff4da: $vhostTemplate->build(); goto C1ffc; B50ff: $siteEntity->setVhostTemplate($vhostTemplate); goto Df4da; E7f8d: goto b5004; goto D3163; E28a5: $vhostTemplate = sprintf("\45\163\45\163", $redirectionVhostTemplate, $vhostTemplate); goto a0edf; F4cba: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Ce951; c4ba2: $phpSiteCreator->createLogrotateFile(); goto D2b32; C428d: $phpSettingsEntity->setPhpVersion($phpVersion); goto Bd153; cfe75: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto F4cba; Fc340: $siteEntity->setCertificate($certificateEntity); goto E2ad9; ab9e3: $certificateEntity = $this->certificateEntityManager->createEntity(); goto c47b7; D0bf4: $phpSite->setRegistrableDomain($registrableDomain); goto e912b; F1e3f: ce75b: goto Bfe9b; Bd153: $phpSettingsEntity->setSite($siteEntity); goto d0ac6; Cde52: $siteEntity->setVarnishCache(true); goto F1e3f; B0493: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto b51e5; c7936: $subdomain = $resolvedDomainName->subDomain()->toString(); goto C590f; Cf103: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\57")), "\x2f"); goto f930d; D2b32: $phpSiteCreator->createIndexPhp(); goto F20d2; af40f: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\57\x2e\56\57\56\56\x2f\162\145\x73\x6f\x75\x72\x63\145\163\x2f\156\x67\151\x6e\170\x2f\166\150\157\163\164\x5f\x74\x65\x6d\160\154\x61\164\x65\57\x72\x65\x64\x69\162\145\143\164"); goto E7f8d; c653c: $phpSite->setUser($siteEntity->getUser()); goto ac39b; F4ec2: if (!(true === is_null($subdomain))) { goto Ce928; } goto f21fc; aa6af: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto f8148; } goto bc8c8; b44f3: $siteEntity->setUserPassword($siteUserPassword); goto e1d63; De6b9: $certificateEntity->setCsr($csr); goto d47aa; Fd070: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto b314f; e5963: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto De6b9; E1d28: $phpSiteCreator->createNginxVhost(); goto f49ad; f6bd7: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto cb1a4; e912b: $phpSite->setSubdomain($subdomain); goto f505f; ea3fa: $csr = $csrGenerator->generate(); goto C3ea8; b956b: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto Cf103; e1d63: $siteEntity->setRootDirectory($rootDirectory); goto C3600; b51e5: $this->siteEntityManager->updateEntity($siteEntity); goto F2dc4; f6891: $phpSite->setPhpSettings($phpSettingsEntity); goto d907b; C3ea8: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto eebbe; A2224: $rsaKeyGenerator = new RsaKeyGenerator(); goto a4a04; D3163: a9606: goto F42cf; Aa238: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto F5847; f32eb: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto c7936; f930d: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto f32eb; B4708: $phpSiteCreator->resetPermissions(); goto Cc77c; D1596: throw new \Exception(implode("\73\x20", $errorMessages)); goto Be66c; Bfacb: a4933: goto B50ff; E390c: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto ea3fa; C66c2: if (!(true === $varnishCache)) { goto d01fa; } goto Ed532; B3d64: $siteEntity->setType(SiteEntity::TYPE_PHP); goto ea5dc; D98b7: $phpSite->setDomainName($domainName); goto D0bf4; bc8c8: $constraintViolationList = new ConstraintViolationList(); goto dae0c; D3c04: $phpSiteCreator->reloadPhpFpmService(); goto C66c2; d907b: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto e4249; ac39b: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto D98b7; f505f: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto e1842; Ed532: $phpSite->setVarnishCache(true); goto Fb6f0; f0b82: $subjectAlternativeNames[] = $registrableDomain; goto B5cf8; c4f96: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto E390c; c110c: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto b3ff2; } goto f0b82; cb1a4: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto f4bdc; e3e72: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto aa6af; d47aa: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto c3d02; Fb6f0: $defaultVarnishCacheSettings = ["\145\156\x61\142\x6c\x65\x64" => false, "\x73\145\x72\x76\145\162" => self::VARNISH_CACHE_SERVER, "\143\x61\143\x68\x65\x54\141\147\x50\x72\145\146\x69\170" => substr(md5(time()), 0, 4)]; goto B85f1; Fac25: $subjectAlternativeNames = []; goto F4ec2; Ce951: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Ff4da; dae0c: $constraintViolationList->addAll($siteConstraints); goto cbad5; c7d68: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto Bcb79; B00f7: $nodejsSiteCreator->installNodejs(); goto Bba9d; F47ca: $siteEntity->setDomainName($domainName); goto C23a6; A24a9: if (true === isset($_ENV["\x41\120\x50\x5f\110\x54\124\x50\x33"]) && "\x74\x72\x75\x65" === $_ENV["\x41\120\x50\x5f\110\x54\124\120\x33"]) { goto ecae2; } goto da178; e8e05: $nodejsSite->setRegistrableDomain($registrableDomain); goto C03cc; A887a: Ea964: goto B85dd; B392c: $nodejsSite->setCertificate($certificateEntity); goto Fe088; C3664: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto bd248; Bd2f3: $subdomain = false === empty($subdomain) ? $subdomain : null; goto E43eb; Dbbfd: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Cbad5; D28c5: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto cb865; F8b1c: $constraintViolationList = new ConstraintViolationList(); goto B78aa; B78aa: $constraintViolationList->addAll($siteConstraints); goto A17ba; ba8fc: $nodejsSiteCreator->resetPermissions(); goto Cd288; a3a24: $nodejsSiteCreator->createNginxVhost(); goto c22e2; Cbad5: $siteEntity = $this->siteEntityManager->createEntity(); goto c3cb6; a9b0d: if (!(true === is_null($subdomain))) { goto b792a; } goto d1c07; d4567: $vhostTemplate = sprintf("\45\x73\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto aff35; d4e74: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto bfde3; c71ad: $siteEntity->setCertificate($certificateEntity); goto Bae62; E43eb: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto Dbbfd; f90ab: b792a: goto f3d54; C158a: if (!(false === empty($redirectionVhostTemplate))) { goto Ea494; } goto d4567; D4581: return $siteEntity; goto de4ee; B9507: $nodejsSettingsEntity->setSite($siteEntity); goto d90c1; A17ba: $constraintViolationList->addAll($nodejsSettingsConstraints); goto C170f; ca11a: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto bea95; ca2b1: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto be054; ec9a4: ecae2: goto D3352; f8c1d: $certificateEntity->setSite($siteEntity); goto B8656; d42bd: $siteEntity->setVhostTemplate($vhostTemplate); goto D28c5; Fe088: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto c3ad8; e5d65: goto fbfe0; goto ec9a4; Bcb79: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto ca11a; E1d9a: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto cbeb3; F809e: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto Cdb39; } goto A24a9; D07c2: $certificateEntity = $this->certificateEntityManager->createEntity(); goto f8c1d; bea95: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Bd2f3; da178: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\56\x2f\x2e\56\57\162\145\x73\x6f\165\162\143\145\x73\x2f\x6e\147\151\156\170\x2f\166\150\157\163\164\x5f\164\145\155\x70\154\141\x74\145\57\x72\x65\x64\x69\x72\145\143\x74"); goto e5d65; C613c: $nodejsSite->setUser($siteEntity->getUser()); goto F9948; A248e: $certificateEntity->setDefaultCertificate(true); goto c1d58; cb865: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto C3664; C03cc: $nodejsSite->setSubdomain($subdomain); goto eb527; Bb952: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f6de4; F9948: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto Ea4c9; d90c1: $siteConstraints = $this->validator->validate($siteEntity); goto E66fa; c3cb6: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto F47ca; Cd288: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto d4e74; Ce5c8: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto C158a; c1d58: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto F31ba; f3d54: if (!(false === is_null($subdomain) && "\167\167\167" == $subdomain)) { goto Ea964; } goto Fa0a7; d1c07: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\56\45\163", $domainName); goto f90ab; F0978: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto a26fe; b1d96: $siteEntity->setRootDirectory($domainName); goto F809e; Ac169: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto a071e; A2b73: Cdb39: goto d42bd; B85dd: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto D3192; D3192: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto A2909; D1f78: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Bb952; eb527: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto B392c; c3ad8: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto F0978; A2909: $csr = $csrGenerator->generate(); goto cfbb3; B8656: $rsaKeyGenerator = new RsaKeyGenerator(); goto ca2b1; cbeb3: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto dbaf1; dbaf1: $vhostTemplate->build(); goto D1f78; E66fa: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto a294f; a294f: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto Da01f; } goto F8b1c; cfbb3: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto A248e; a071e: Da01f: goto D07c2; a26fe: $nodejsSiteCreator->createUser(); goto f6f96; aff35: Ea494: goto A2b73; A56ba: $certificateEntity->setCertificate($selfSignedCertificate); goto c71ad; c22e2: $nodejsSiteCreator->reloadNginxService(); goto ba8fc; f6de4: $this->siteEntityManager->updateEntity($siteEntity); goto D4581; Ea4c9: $nodejsSite->setDomainName($domainName); goto e8e05; a96a2: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto A56ba; D79cc: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto E1d9a; be054: $subjectAlternativeNames = []; goto a9b0d; b6afd: fbfe0: goto Ce5c8; F31ba: $certificateEntity->setCsr($csr); goto a96a2; Fa0a7: $subjectAlternativeNames[] = $registrableDomain; goto A887a; Bba9d: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto a3a24; C23a6: $siteEntity->setUser($siteUser); goto B4b3a; E20c8: $nodejsSiteCreator->createLogrotateFile(); goto cab56; bd248: $nodejsSettingsEntity->setPort($port); goto B9507; Bae62: $nodejsSite = new NodejsSite(); goto C613c; D3352: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\56\x2e\57\56\56\57\162\x65\163\x6f\x75\x72\143\x65\x73\57\x6e\x67\151\x6e\170\x2f\x76\x68\x6f\x73\x74\x5f\x74\x65\155\x70\x6c\141\x74\x65\x2f\x72\x65\144\151\162\x65\x63\164\x2d\x68\164\164\160\x33"); goto b6afd; C170f: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Ac169; cab56: $nodejsSiteCreator->createNvmDirectory(); goto B00f7; bfde3: $vhostTemplate->resetProcessors(); goto D79cc; f6f96: $nodejsSiteCreator->createRootDirectory(); goto E20c8; B4b3a: $siteEntity->setUserPassword($siteUserPassword); goto b1d96; de4ee: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto C84c7; f7efe: $siteEntity->setUserPassword($siteUserPassword); goto Ac005; B5a55: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto a47a1; e05d6: $pythonSite->setUser($siteEntity->getUser()); goto a4759; d6f77: $pythonSiteCreator->writePythonVersionFile(); goto B5a55; C2a8f: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto b71e6; Be246: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto adc12; B7152: $pythonSite->setRegistrableDomain($registrableDomain); goto c136d; e53ad: $pythonSettingsEntity->setSite($siteEntity); goto Bd949; Bd949: $siteConstraints = $this->validator->validate($siteEntity); goto fc9e6; E6de8: $vhostTemplate->resetProcessors(); goto C2a8f; Ac005: $siteEntity->setRootDirectory($domainName); goto Efbd3; fd300: $pythonSiteCreator->createRootDirectory(); goto C38f7; Db6b1: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto C253f; f7ea5: $pythonSiteCreator->createUser(); goto fd300; bf8d4: ea869: goto Fc58f; ae1f4: $siteEntity->setUser($siteUser); goto f7efe; fc9e6: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto F9fb7; Ba169: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\x2e\56\x2f\x2e\56\57\162\x65\163\x6f\x75\x72\x63\145\x73\57\156\147\151\x6e\x78\57\166\150\x6f\163\x74\x5f\164\x65\155\160\154\141\x74\145\x2f\x72\x65\x64\x69\162\x65\x63\x74"); goto B5522; F165f: if (!(false === empty($redirectionVhostTemplate))) { goto Be22b; } goto fff1d; Ba0e1: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto b7b01; B5522: goto b4f7b; goto Ce1e5; Ce1e5: Bf492: goto F5935; De564: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto bfd66; F42bb: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto f7ea5; b7b01: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto E6de8; C9e72: $certificateEntity->setCsr($csr); goto E4a6b; b980f: $subjectAlternativeNames[] = sprintf("\x77\x77\167\x2e\x25\163", $domainName); goto Ccd10; bd476: if (!(true === is_null($subdomain))) { goto Abb36; } goto b980f; da727: $subjectAlternativeNames = []; goto bd476; ed06a: $siteEntity = $this->siteEntityManager->createEntity(); goto d7859; A4385: $siteEntity->setDomainName($domainName); goto ae1f4; D5674: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto F165f; e4a23: $constraintViolationList->addAll($siteConstraints); goto cd43d; f1c33: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto a3d44; e5f66: $pythonSite->setCertificate($certificateEntity); goto F4ade; c05f0: b4f7b: goto D5674; F5935: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\x2e\56\x2f\x2e\x2e\57\x72\145\x73\157\x75\x72\143\145\163\57\x6e\147\151\156\x78\57\x76\150\x6f\163\x74\x5f\164\145\x6d\x70\x6c\x61\164\145\x2f\x72\145\144\x69\162\145\x63\164\55\x68\164\164\160\63"); goto c05f0; E796a: $pythonSiteCreator->reloadNginxService(); goto b3d0c; c230e: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto B74ac; a7606: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto debdd; bfd66: $this->siteEntityManager->updateEntity($siteEntity); goto Abead; Cdf1d: $pythonSettingsEntity = new PythonSettingsEntity(); goto Fd739; F9fb7: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto b575c; } goto bbbeb; cd43d: $constraintViolationList->addAll($pythonSettingsConstraints); goto B4b66; f60fc: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto C9e72; fff1d: $vhostTemplate = sprintf("\x25\163\45\163", $redirectionVhostTemplate, $vhostTemplate); goto D77b9; Ac72d: if (true === isset($_ENV["\x41\x50\x50\x5f\110\124\124\120\x33"]) && "\164\x72\165\145" === $_ENV["\x41\120\120\x5f\110\124\124\120\63"]) { goto Bf492; } goto Ba169; Efbd3: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto C6d04; } goto Ac72d; d161c: if (!(false === is_null($subdomain) && "\167\x77\x77" == $subdomain)) { goto ea869; } goto Fd293; c136d: $pythonSite->setSubdomain($subdomain); goto bc3ad; b71e6: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Db6b1; debdd: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto ed06a; Ed87b: $certificateEntity->setCertificate($selfSignedCertificate); goto D655a; bbbeb: $constraintViolationList = new ConstraintViolationList(); goto e4a23; D655a: $siteEntity->setCertificate($certificateEntity); goto fb2cf; Ed1ae: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto c6320; f0d7f: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto da727; B4b66: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto f1c33; a2fef: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto f8be0; b3d0c: $pythonSiteCreator->resetPermissions(); goto Ba0e1; bc3ad: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto e5f66; Abead: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto b3eb9; Fc58f: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Be246; C84c7: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto c230e; C253f: $vhostTemplate->build(); goto De564; A97bf: C6d04: goto Cc790; F4ade: $pythonSite->setPythonSettings($pythonSettingsEntity); goto C9271; D77b9: Be22b: goto A97bf; Cc790: $siteEntity->setVhostTemplate($vhostTemplate); goto Cdf1d; B74ac: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f145f; a4759: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto a5732; a3d44: b575c: goto e1e1a; e1e1a: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Ebfe2; f8be0: $certificateEntity->setDefaultCertificate(true); goto f60fc; Ccd10: Abb36: goto d161c; fb2cf: $pythonSite = new PythonSite(); goto e05d6; a5732: $pythonSite->setDomainName($domainName); goto B7152; d7859: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto A4385; C9271: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto F42bb; C38f7: $pythonSiteCreator->createLogrotateFile(); goto d6f77; adc12: $csr = $csrGenerator->generate(); goto a2fef; Fd293: $subjectAlternativeNames[] = $registrableDomain; goto bf8d4; b3eb9: return $siteEntity; goto Cdfc1; Ebfe2: $certificateEntity->setSite($siteEntity); goto Aec39; c6320: $pythonSettingsEntity->setPort($port); goto e53ad; f145f: $subdomain = false === empty($subdomain) ? $subdomain : null; goto a7606; Fd739: $siteEntity->setPythonSettings($pythonSettingsEntity); goto Ed1ae; E4a6b: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Ed87b; Aec39: $rsaKeyGenerator = new RsaKeyGenerator(); goto f0d7f; a47a1: $pythonSiteCreator->createNginxVhost(); goto E796a; Cdfc1: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto Bd32a; Ca821: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto a6325; Bae8e: $siteEntity = $this->siteEntityManager->createEntity(); goto cac96; D44d0: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto cd2f3; fbcb4: if (!(false === is_null($subdomain) && "\x77\167\x77" == $subdomain)) { goto Be68d; } goto F378e; a85bc: $staticSite->setDomainName($domainName); goto f75c9; d80fa: c103b: goto abe1f; a6325: $subdomain = $resolvedDomainName->subDomain()->toString(); goto b254f; D4194: $certificateEntity->setSite($siteEntity); goto E86e5; D940b: goto f3207; goto d80fa; E5a56: $siteEntity->setVhostTemplate($vhostTemplate); goto cbd54; Be0f7: $staticSite->setUser($siteEntity->getUser()); goto Ad223; ca62e: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto Bf91e; Eb9d6: $staticSite = new StaticSite(); goto Be0f7; B9bbb: Be68d: goto D87cb; d8af6: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto c41e4; } goto A8aea; D583e: if (!count($siteConstraints)) { goto D5421; } goto F7413; Bc2e7: throw new \Exception(implode("\73\x20", $errorMessages)); goto Bc9e4; C7ca0: $staticSite->setCertificate($certificateEntity); goto C6fa9; Eb52a: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Dc9cb; b096b: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Fd8ba; b1177: $siteEntity->setUserPassword($siteUserPassword); goto c484a; A2093: $staticSite->setSubdomain($subdomain); goto b1c69; Ce612: $vhostTemplate = sprintf("\x25\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto F0d01; Ed97c: $staticSiteCreator->createPrivateKeyAndCertificate(); goto b35b0; e5b44: $this->siteEntityManager->updateEntity($siteEntity); goto b992b; E32c4: $staticSiteCreator->createRootDirectory(); goto Fa5dc; Af5a2: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto C1211; ce366: $vhostTemplate->build(); goto Af5a2; Bd32a: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Ca821; Fd8ba: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto D1d2b; cd8d1: $siteEntity->setCertificate($certificateEntity); goto Eb9d6; ddeeb: $staticSiteCreator->reloadNginxService(); goto c0d1d; c8cf7: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Bc2e7; C1211: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto e5b44; f75c9: $staticSite->setRegistrableDomain($registrableDomain); goto A2093; b1c69: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto C7ca0; Bf91e: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Bae8e; B064c: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\x2e\56\x2f\56\x2e\x2f\x72\x65\163\157\x75\162\143\x65\163\57\x6e\147\151\156\170\57\x76\150\x6f\163\164\x5f\164\145\x6d\160\x6c\141\164\x65\x2f\162\145\x64\x69\162\x65\x63\x74"); goto D940b; c0d1d: $staticSiteCreator->resetPermissions(); goto Ecd16; c859c: f3207: goto D44d0; Fa5dc: $staticSiteCreator->createLogrotateFile(); goto D3abb; b561f: if (!(true === is_null($subdomain))) { goto f3ce6; } goto F9ce6; A8aea: if (true === isset($_ENV["\101\x50\x50\x5f\x48\124\124\x50\63"]) && "\164\162\x75\145" === $_ENV["\x41\x50\120\x5f\110\x54\124\120\x33"]) { goto c103b; } goto B064c; f2672: $constraintViolationList->addAll($siteConstraints); goto c8cf7; F9ce6: $subjectAlternativeNames[] = sprintf("\x77\167\x77\x2e\x25\163", $domainName); goto cae68; dc44a: $certificateEntity->setCertificate($selfSignedCertificate); goto cd8d1; b35b0: $staticSiteCreator->createNginxVhost(); goto ddeeb; cd2f3: if (!(false === empty($redirectionVhostTemplate))) { goto bc329; } goto Ce612; bdc85: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto e666c; Ad223: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto a85bc; cac96: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto A1fa2; A1fa2: $siteEntity->setDomainName($domainName); goto b9b9b; Dc9cb: $vhostTemplate->resetProcessors(); goto b096b; E86e5: $rsaKeyGenerator = new RsaKeyGenerator(); goto C7bc1; F0d01: bc329: goto eec3a; D1d2b: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto ce366; aed86: $staticSiteCreator->createUser(); goto E32c4; eec3a: c41e4: goto E5a56; Bc9e4: D5421: goto Dca83; Ecd16: $vhostTemplate = new StaticVhostTemplate($staticSite); goto Eb52a; Dca83: $certificateEntity = $this->certificateEntityManager->createEntity(); goto D4194; D87cb: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto bdc85; bcc49: $subjectAlternativeNames = []; goto b561f; F378e: $subjectAlternativeNames[] = $registrableDomain; goto B9bbb; C7bc1: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto bcc49; b254f: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ca62e; F7413: $constraintViolationList = new ConstraintViolationList(); goto f2672; db0df: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Bc4d8; cbd54: $siteConstraints = $this->validator->validate($siteEntity); goto D583e; cae68: f3ce6: goto fbcb4; Bc4d8: $certificateEntity->setDefaultCertificate(true); goto B727e; D3abb: $staticSiteCreator->createIndexHtml(); goto Ed97c; B727e: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Cbbf1; e666c: $csr = $csrGenerator->generate(); goto db0df; b992b: return $siteEntity; goto ff87a; abe1f: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\x2e\x2f\x2e\56\x2f\162\145\163\157\165\162\x63\x65\x73\57\x6e\x67\151\x6e\170\x2f\x76\150\157\x73\x74\137\164\x65\x6d\x70\154\x61\164\145\57\x72\145\144\151\162\x65\x63\164\x2d\150\164\164\160\x33"); goto c859c; C6fa9: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Bd839; e6541: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto dc44a; b9b9b: $siteEntity->setUser($siteUser); goto b1177; c484a: $siteEntity->setRootDirectory($domainName); goto d8af6; Cbbf1: $certificateEntity->setCsr($csr); goto e6541; Bd839: $staticSiteCreator = new StaticSiteCreator($staticSite); goto aed86; ff87a: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto f93e4; Aa598: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto F649e; F649e: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Ac47c; D6c87: if (!(true === is_null($subdomain))) { goto Da8c5; } goto B6f20; Ad5d7: $subdomain = $resolvedDomainName->subDomain()->toString(); goto fc889; Df496: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f7a12; ef24a: cc879: goto A3970; C5dbb: $siteEntity->setUserPassword($siteUserPassword); goto d1615; E75d6: return $siteEntity; goto E56e6; C3cc0: $siteConstraints = $this->validator->validate($siteEntity); goto E61a7; d1615: $siteEntity->setRootDirectory($domainName); goto F0d91; e3ba6: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto e4ea5; bf4fa: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto B9b92; Ac47c: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto e300a; fc889: $subdomain = false === empty($subdomain) ? $subdomain : null; goto db7cb; A95bf: $siteEntity->setDomainName($domainName); goto D621d; A5ca5: $reversProxySiteCreator->createLogrotateFile(); goto C79df; f0937: $reversProxySiteCreator->createRootDirectory(); goto A5ca5; A1f21: $subjectAlternativeNames = []; goto D6c87; E5b5e: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Df496; A3970: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\x2e\x2e\x2f\x2e\56\57\162\145\x73\x6f\x75\x72\143\x65\163\x2f\156\147\x69\156\170\57\166\150\157\x73\x74\137\x74\x65\155\x70\x6c\141\x74\x65\x2f\x72\x65\144\x69\x72\x65\x63\164\55\x68\164\x74\160\63"); goto b83af; E61e7: if (!(true === is_null($subdomain) || "\x77\x77\x77" == $subdomain)) { goto a7983; } goto C780b; a4055: Da8c5: goto Eec94; ade0e: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Abffb; db7cb: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto d13d6; ae221: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto abefc; d992b: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto e420c; bc0a3: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto A1f21; e420c: $certificateEntity->setDefaultCertificate(true); goto d43ef; e2831: $certificateEntity->setCsr($csr); goto f2b86; f93e4: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto B0d4d; f1633: a7983: goto d6b09; F1e8d: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto Fd09e; f12bf: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto A95bf; d13d6: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Cba3c; F0d91: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto E61e7; f7a12: $this->siteEntityManager->updateEntity($siteEntity); goto E75d6; b83af: a75b5: goto b5d88; Dc893: $certificateEntity->setCertificate($selfSignedCertificate); goto a946d; A9284: fd4cc: goto e5a16; B119e: $reversProxySiteCreator->createUser(); goto f0937; ef2b2: $vhostTemplate = sprintf("\45\x73\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto ec1f5; e1228: $reversProxySiteCreator->reloadNginxService(); goto Fcc11; B9d2b: if (!(false === empty($redirectionVhostTemplate))) { goto fbaa3; } goto ef2b2; d6b09: $siteEntity->setVhostTemplate($vhostTemplate); goto C3cc0; e4ea5: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto B119e; Fd09e: $reverseProxySite->setDomainName($domainName); goto C72b7; a946d: $siteEntity->setCertificate($certificateEntity); goto e02f5; B0d4d: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Ad5d7; Bd597: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto A61cb; e5a16: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto dbfef; B9b92: $reverseProxySite->setCertificate($certificateEntity); goto B70b3; e02f5: $reverseProxySite = new ReverseProxySite(); goto c07e3; f1ad7: $constraintViolationList = new ConstraintViolationList(); goto F4214; D5e14: $csr = $csrGenerator->generate(); goto d992b; Beed2: goto a75b5; goto ef24a; B6f20: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\x2e\x25\163", $domainName); goto a4055; Cba3c: $siteEntity = $this->siteEntityManager->createEntity(); goto f12bf; Eec94: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto fd4cc; } goto c9684; Abffb: $certificateEntity->setSite($siteEntity); goto Ecfbe; B70b3: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto e3ba6; C79df: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto Bd7f2; C72b7: $reverseProxySite->setRegistrableDomain($registrableDomain); goto a00e2; c9684: $subjectAlternativeNames[] = $registrableDomain; goto A9284; f2b86: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Dc893; C780b: if (true === isset($_ENV["\x41\x50\x50\137\x48\124\124\x50\63"]) && "\164\162\165\x65" === $_ENV["\101\120\120\137\x48\x54\124\x50\x33"]) { goto cc879; } goto Ba369; abefc: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto E210f; d43ef: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto e2831; Ba369: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\x2e\x2e\x2f\56\56\57\x72\145\163\x6f\x75\162\x63\145\x73\57\156\x67\x69\156\x78\x2f\166\150\157\x73\164\137\x74\145\x6d\x70\x6c\141\x74\x65\x2f\x72\145\x64\151\x72\145\x63\x74"); goto Beed2; dbfef: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto D5e14; Ecfbe: $rsaKeyGenerator = new RsaKeyGenerator(); goto bc0a3; D621d: $siteEntity->setUser($siteUser); goto C5dbb; E61a7: if (!count($siteConstraints)) { goto Ab7b9; } goto f1ad7; F4214: $constraintViolationList->addAll($siteConstraints); goto aa6f8; ec1f5: fbaa3: goto f1633; aa6f8: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Bd597; c07e3: $reverseProxySite->setUser($siteEntity->getUser()); goto F1e8d; A61cb: Ab7b9: goto ade0e; Fcc11: $reversProxySiteCreator->resetPermissions(); goto ae221; a00e2: $reverseProxySite->setSubdomain($subdomain); goto bf4fa; e300a: $vhostTemplate->build(); goto E5b5e; E210f: $vhostTemplate->resetProcessors(); goto Aa598; b5d88: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto B9d2b; Bd7f2: $reversProxySiteCreator->createNginxVhost(); goto e1228; E56e6: } public function installedWordPressSite(Request $request) : Response { goto f44c6; ba82f: return $response; goto Ae98d; C5f9e: goto E52b8; goto bbccd; f44c6: $session = $request->getSession(); goto d6aaa; a5d63: return $response; goto de2f4; de2f4: E52b8: goto ba82f; d6aaa: $siteCredentials = $session->get("\x73\x69\164\145\103\x72\145\144\x65\156\164\151\141\x6c\163"); goto Fb7d3; bbccd: a0ee0: goto B3d45; Fb7d3: if (false === empty($siteCredentials)) { goto a0ee0; } goto a0379; B3d45: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto ba094; ba094: $response = $this->render("\106\x72\x6f\156\x74\x65\x6e\144\57\123\x69\x74\x65\57\x4e\145\x77\57\x77\x6f\162\144\x70\162\x65\x73\163\55\151\x6e\x73\x74\141\x6c\154\145\144\x2e\x68\164\155\154\56\x74\x77\151\147", ["\163\151\164\x65\x43\162\x65\144\x65\x6e\x74\x69\141\x6c\x73" => $siteCredentials]); goto a5d63; a0379: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\163\x69\x74\145\x73")); goto C5f9e; Ae98d: } private function renderSiteCredentials(array $siteCredentials) : string { goto E46fd; dc070: foreach ($siteCredentials as $section => $sectionData) { goto Df223; f1033: $renderedCredentials .= "\55\x2d\x2d\55\55\55\55\55\55\55\55\x2d\55\x2d\x2d\55\x2d\55\55\x2d\55\55\55\x2d\55\55\x2d\x2d\x2d\x2d\55\x2d\55\x2d\x2d\x2d\x2d\55\x2d\x2d\x2d\55\x2d\x2d\55\x2d\55\55\x2d\55\55\x2d\x2d\x2d" . PHP_EOL; goto c6163; Ade51: $renderedCredentials .= PHP_EOL; goto Cb60e; Df223: $renderedCredentials .= $section . PHP_EOL; goto f1033; Cb60e: b9a9e: goto a37f3; E7cdf: c2f91: goto Ade51; c6163: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\x73\x3a\x20\x25\x73", $key, $value) . PHP_EOL; B1311: } goto E7cdf; a37f3: } goto a8c67; E46fd: $renderedCredentials = ''; goto dc070; a8c67: a3aba: goto E155f; E155f: return $renderedCredentials; goto fa283; fa283: } private function getVhostTemplateEntity(string $name) : mixed { goto Da659; Da659: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto e15e2; Af39b: throw new \Exception($this->translator->trans("\126\150\157\163\x74\x20\x54\145\155\x70\x6c\x61\x74\x65\x20\x25\x76\x68\x6f\x73\x74\124\145\x6d\x70\x6c\141\164\145\x25\x20\x64\157\145\163\40\156\157\x74\40\145\170\151\163\x74\x2e", ["\45\x76\x68\x6f\163\x74\124\145\155\160\x6c\x61\164\x65\x25" => $name])); goto B5bd7; e15e2: if (!(true === is_null($vhostTemplateEntity))) { goto c477e; } goto Af39b; B1738: return $vhostTemplateEntity; goto D3c75; B5bd7: c477e: goto B1738; D3c75: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto Cf904; eb695: return $errorMessages; goto A3383; Ec2aa: B4db9: goto eb695; Cf904: $errorMessages = []; goto Dd7d1; Dd7d1: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\x73\x3a\x20\45\163", $constraint->getPropertyPath(), $constraint->getMessage()); Db1c7: } goto Ec2aa; A3383: } private function generateNameFromDomainName(string $domainName) : string { goto D79ad; Af1aa: if (!(false === empty($subdomain))) { goto ba57f; } goto d4a5f; e5c40: e4838: goto df9f4; D79ad: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto a1a0e; f9959: $subdomain = $resolvedDomainName->subDomain()->toString(); goto e986c; e986c: $explodedRegistrableDomain = explode("\x2e", $registrableDomain); goto C1c6b; Ef46d: e29dd: goto Ce81a; Ce81a: return $name; goto Dc6f9; a1a0e: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto f9959; C1c6b: if ("\x77\167\167" == $subdomain) { goto e4838; } goto D195a; d4a5f: $explodedSubdomain = explode("\56", $subdomain); goto C6ea6; D989c: goto e29dd; goto e5c40; fca55: ba57f: goto D989c; D195a: $name = $explodedRegistrableDomain[0] ?? ''; goto Af1aa; df9f4: $name = $explodedRegistrableDomain[0] ?? ''; goto Ef46d; C6ea6: $name = sprintf("\x25\x73\x2d\45\x73", $explodedRegistrableDomain[0] ?? '', implode("\55", $explodedSubdomain)); goto fca55; Dc6f9: } private function getUniqueDatabaseName(string $databaseName) : string { goto eaf83; dbf1b: $uniqueDatabaseName = sprintf("\x25\x73\x2d\x25\x73", $databaseName, $i); goto D35ce; F1c3e: return $uniqueDatabaseName; goto a773a; B8745: $i = 0; goto Dfc65; Ed0b5: $uniqueDatabaseName = sprintf("\45\163\55\x64\x62", $uniqueDatabaseName); goto c923a; C3783: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto df75d; eaf83: $uniqueDatabaseName = $databaseName; goto f8553; df75d: $databases = $databaseConnection->getDatabases(); goto Cc116; c06ff: $databaseExists = in_array($uniqueDatabaseName, $databases); goto D0e45; f8553: if (!(strlen($uniqueDatabaseName) <= 3)) { goto Fd393; } goto Ed0b5; f8bc1: if (!(0 < $i)) { goto E2a76; } goto dbf1b; D35ce: E2a76: goto c06ff; b3bc5: B722d: goto F1c3e; b067a: if (true === $databaseExists) { goto a426d; } goto b3bc5; Dfc65: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto C3783; Cc116: a426d: goto f8bc1; D0e45: $i++; goto b067a; c923a: Fd393: goto B8745; a773a: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto F3ea5; e6e29: D5224: goto Bdb20; F3ea5: $uniqueDatabaseUserName = $databaseUserName; goto B3cb8; aa026: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto F0d1f; F79d7: $i = 0; goto a43c9; B3cb8: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto b63ed; } goto a2c9a; F57fc: b63ed: goto F79d7; Bdb20: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto Ab54d; F0d1f: return $uniqueDatabaseUserName; goto F7f4a; a43c9: feeda: goto eec42; eec42: if (!(0 < $i)) { goto D5224; } goto d9064; a4a2f: e7312: goto aa026; d4d0f: if (false === is_null($databaseUserEntity)) { goto feeda; } goto a4a2f; Ab54d: $i++; goto d4d0f; a2c9a: $uniqueDatabaseUserName = sprintf("\x25\x73\x2d\x64\x62", $uniqueDatabaseUserName); goto F57fc; d9064: $uniqueDatabaseUserName = sprintf("\45\x73\55\45\163", $databaseUserName, $i); goto e6e29; F7f4a: } private function hasPermissions() : bool { goto D5c6c; ac64b: D9bc9: goto F2319; fdee6: return true; goto ac64b; F2319: return false; goto D4a44; D5c6c: $user = $this->getUser(); goto b0dbb; b0dbb: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto D9bc9; } goto fdee6; D4a44: } }
